@@ -2,13 +2,11 @@
 # Copyright (c) Vispy Development Team. All Rights Reserved.
 # Distributed under the (new) BSD License. See LICENSE.txt for more info.
 
-"""
-vispy backend for pyglet.
-"""
+"""vispy backend for pyglet."""
 
 from __future__ import division
 
-from distutils.version import LooseVersion
+from packaging.version import Version
 from time import sleep
 
 from ..base import (BaseApplicationBackend, BaseCanvasBackend,
@@ -25,7 +23,7 @@ USE_EGL = config['gl_backend'].lower().startswith('es')
 try:
     import pyglet
     version = pyglet.version
-    if LooseVersion(version) < LooseVersion('1.2'):
+    if Version(version) < Version('1.2'):
         help_ = ('You can install the latest pyglet using:\n    '
                  'pip install http://pyglet.googlecode.com/archive/tip.zip')
         raise ImportError('Pyglet version too old (%s), need >= 1.2\n%s'
@@ -167,13 +165,11 @@ class ApplicationBackend(BaseApplicationBackend):
 
 # ------------------------------------------------------------------ canvas ---
 
-class CanvasBackend(_Window, BaseCanvasBackend):
+class CanvasBackend(BaseCanvasBackend, _Window):
+    """Pyglet backend for Canvas abstract class."""
 
-    """ Pyglet backend for Canvas abstract class."""
-
-    # args are for BaseCanvasBackend, kwargs are for us.
-    def __init__(self, *args, **kwargs):
-        BaseCanvasBackend.__init__(self, *args)
+    def __init__(self, vispy_canvas, **kwargs):
+        BaseCanvasBackend.__init__(self, vispy_canvas)
         p = self._process_backend_kwargs(kwargs)
 
         # Deal with config
@@ -275,6 +271,12 @@ class CanvasBackend(_Window, BaseCanvasBackend):
         w, h = self.get_size()
         return w, h
 
+    def _vispy_get_physical_size(self):
+        if self._vispy_canvas is None:
+            return
+        w, h = self.get_framebuffer_size()
+        return w, h
+
     def _vispy_get_position(self):
         x, y = self.get_location()
         return x, y
@@ -341,7 +343,7 @@ class CanvasBackend(_Window, BaseCanvasBackend):
                 button=BUTTONMAP.get(button, 0),
                 modifiers=self._modifiers(),
             )
-            #self._buttons_accepted &= ~button
+            # self._buttons_accepted &= ~button
 
     def on_mouse_motion(self, x, y, dx, dy):
         if self._vispy_canvas is None:
