@@ -35,10 +35,21 @@ from .buffer import VertexBuffer, IndexBuffer, DataBuffer
 from .texture import BaseTexture, Texture2D, Texture3D, Texture1D, TextureCube
 from ..util import logger
 from .util import check_enum
-from ..ext.six import string_types
 from .context import get_current_canvas
 from .preprocessor import preprocess
 
+# ------------------------------------------------------------ Constants ---
+REGEX_VAR = {}
+for kind in ('uniform', 'attribute', 'varying', 'const', 'in', 'out'):
+    REGEX_VAR[kind] = re.compile(fr"\s*{kind}\s+"  # kind of variable
+                                 r"((highp|mediump|lowp)\s+)?"  # Precision (optional)
+                                 r"(?P<type>\w+)\s+"  # type
+                                 r"(?P<name>\w+)\s*"  # name
+                                 r"(\[(?P<size>\d+)\])?"  # size (optional)
+                                 r"(\s*\=\s*[0-9.]+)?"  # default value (optional)
+                                 r"\s*;",  # end
+                                 flags=re.MULTILINE)
+    
 
 # ------------------------------------------------------------ Shader class ---
 class Shader(GLObject):
@@ -72,7 +83,7 @@ class GeometryShader(Shader):
 
 # ----------------------------------------------------------- Program class ---
 class Program(GLObject):
-    """ Shader program object
+    """Shader program object
 
     A Program is an object to which shaders can be attached and linked to
     create the final program.
@@ -101,25 +112,25 @@ class Program(GLObject):
     _GLIR_TYPE = 'Program'
 
     _gtypes = {  # DTYPE, NUMEL
-        'float':        (np.float32, 1),
-        'vec2':         (np.float32, 2),
-        'vec3':         (np.float32, 3),
-        'vec4':         (np.float32, 4),
-        'int':          (np.int32,   1),
-        'ivec2':        (np.int32,   2),
-        'ivec3':        (np.int32,   3),
-        'ivec4':        (np.int32,   4),
-        'bool':         (np.int32,   1),
-        'bvec2':        (np.bool,    2),
-        'bvec3':        (np.bool,    3),
-        'bvec4':        (np.bool,    4),
-        'mat2':         (np.float32, 4),
-        'mat3':         (np.float32, 9),
-        'mat4':         (np.float32, 16),
-        'sampler1D':    (np.uint32, 1),
-        'sampler2D':    (np.uint32, 1),
-        'sampler3D':    (np.uint32, 1),
-        'samplerCube':  (np.uint32, 1),
+        'float': (np.float32, 1),
+        'vec2': (np.float32, 2),
+        'vec3': (np.float32, 3),
+        'vec4': (np.float32, 4),
+        'int': (np.int32, 1),
+        'ivec2': (np.int32, 2),
+        'ivec3': (np.int32, 3),
+        'ivec4': (np.int32, 4),
+        'bool': (np.int32, 1),
+        'bvec2': (bool, 2),
+        'bvec3': (bool, 3),
+        'bvec4': (bool, 4),
+        'mat2': (np.float32, 4),
+        'mat3': (np.float32, 9), 
+        'mat4': (np.float32, 16),
+        'sampler1D': (np.uint32, 1),
+        'sampler2D': (np.uint32, 1),
+        'sampler3D': (np.uint32, 1),
+        'samplerCube': (np.uint32, 1),
     }
 
     # ---------------------------------
@@ -128,7 +139,7 @@ class Program(GLObject):
 
         # Init source code for vertex and fragment shader
         self._shaders = None, None
-        
+
         # Init description of variables obtained from source code
         self._code_variables = {}  # name -> (kind, type_, name)
         # Init user-defined data for attributes and uniforms
@@ -141,7 +152,7 @@ class Program(GLObject):
         # unncessary
 
         # Check and set shaders
-        if isinstance(vert, string_types) and isinstance(frag, string_types):
+        if isinstance(vert, str) and isinstance(frag, str):
             self.set_shaders(vert, frag)
         elif not (vert is None and frag is None):
             raise ValueError('Vert and frag must either both be str or None')
@@ -163,7 +174,7 @@ class Program(GLObject):
             self.bind(VertexBuffer(self._buffer))
 
     def set_shaders(self, vert, frag, geom=None, update_variables=True):
-        """ Set the vertex and fragment shaders.
+        """Set the vertex and fragment shaders.
 
         Parameters
         ----------
@@ -188,7 +199,7 @@ class Program(GLObject):
         for shader in shaders:
             self.glir.associate(shader.glir)
             self._glir.command('ATTACH', self._id, shader.id)
-        
+
         # Store source code, send it to glir, parse the code for variables
         self._shaders = shaders
 
@@ -207,16 +218,15 @@ class Program(GLObject):
         self._user_variables = {}
         # Parse code (and process pending variables)
         self._parse_variables_from_code(update_variables=update_variables)
-    
+
     @property
     def shaders(self):
-        """ All currently attached shaders
-        """
+        """All currently attached shaders"""
         return self._shaders
 
     @property
     def variables(self):
-        """ A list of the variables in use by the current program
+        """A list of the variables in use by the current program
 
         The list is obtained by parsing the GLSL source code.
 
@@ -230,30 +240,19 @@ class Program(GLObject):
         # Note that internally the variables are stored as a dict
         # that maps names -> tuples, for easy looking up by name.
         return [x[:3] for x in self._code_variables.values()]
-   
-    def _parse_variables_from_code(self, update_variables=True):
-        """ Parse uniforms, attributes and varyings from the source code.
-        """
 
+    def _parse_variables_from_code(self, update_variables=True):
+        """Parse uniforms, attributes and varyings from the source code."""
         # Get one string of code with comments removed
         code = '\n\n'.join([sh.code for sh in self._shaders])
         code = re.sub(r'(.*)(//.*)', r'\1', code, re.M)
-        
-        # Regexp to look for variable names
-        var_regexp = (r"\s*VARIABLE\s+"  # kind of variable
-                      r"((highp|mediump|lowp)\s+)?"  # Precision (optional)
-                      r"(?P<type>\w+)\s+"  # type
-                      r"(?P<name>\w+)\s*"  # name
-                      r"(\[(?P<size>\d+)\])?"  # size (optional)
-                      r"(\s*\=\s*[0-9.]+)?"  # default value (optional)
-                      r"\s*;"  # end
-                      )
 
         # Parse uniforms, attributes and varyings
         self._code_variables = {}
         for kind in ('uniform', 'attribute', 'varying', 'const', 'in', 'out'):
-            regex = re.compile(var_regexp.replace('VARIABLE', kind),
-                               flags=re.MULTILINE)
+
+            # pick regex for the correct kind of var
+            reg = REGEX_VAR[kind]
 
             # treat *in* like attribute, *out* like varying
             if kind == 'in':
@@ -261,7 +260,7 @@ class Program(GLObject):
             elif kind == 'out':
                 kind = 'varying'
 
-            for m in re.finditer(regex, code):
+            for m in re.finditer(reg, code):
                 gtype = m.group('type')
                 size = int(m.group('size')) if m.group('size') else -1
                 this_kind = kind
@@ -280,7 +279,7 @@ class Program(GLObject):
             self._process_pending_variables()
 
     def bind(self, data):
-        """ Bind a VertexBuffer that has structured data
+        """Bind a VertexBuffer that has structured data
 
         Parameters
         ----------
@@ -296,8 +295,7 @@ class Program(GLObject):
             self[name] = data[name]
 
     def _process_pending_variables(self):
-        """ Try to apply the variables that were set but not known yet.
-        """
+        """Try to apply the variables that were set but not known yet."""
         # Clear our list of pending variables
         self._pending_variables, pending = {}, self._pending_variables
         # Try to apply it. On failure, it will be added again
@@ -305,7 +303,7 @@ class Program(GLObject):
             self[name] = data
 
     def __setitem__(self, name, data):
-        """ Setting uniform or attribute data
+        """Setting uniform or attribute data
 
         This method requires the information about the variable that we
         know from parsing the source code. If this information is not
@@ -328,7 +326,6 @@ class Program(GLObject):
         are no longer present or active in the new source code that is
         about to be set.
         """
-
         # Deal with local buffer storage (see count argument in __init__)
         if (self._buffer is not None) and not isinstance(data, DataBuffer):
             if name in self._buffer.dtype.names:
@@ -423,11 +420,12 @@ class Program(GLObject):
                             raise ValueError('data.shape[-1] must be %s '
                                              'not %s for %s'
                                              % (numel, data._last_dim, name))
+                    divisor = getattr(data, 'divisor', None)
                     self._user_variables[name] = data
                     value = (data.id, data.stride, data.offset)
                     self.glir.associate(data.glir)
                     self._glir.command('ATTRIBUTE', self._id,
-                                       name, type_, value)
+                                       name, type_, value, divisor)
                 else:
                     # Single-value attribute; convert to array and check size
                     dtype, numel = self._gtypes[type_]
@@ -437,11 +435,12 @@ class Program(GLObject):
                     if data.size != numel:
                         raise ValueError('Attribute %r needs %i elements, '
                                          'not %i.' % (name, numel, data.size))
+                    divisor = getattr(data, 'divisor', None)
                     # Store and send GLIR command
                     self._user_variables[name] = data
                     value = tuple([0] + [i for i in data])
                     self._glir.command('ATTRIBUTE', self._id,
-                                       name, type_, value)
+                                       name, type_, value, divisor)
             else:
                 raise KeyError('Cannot set data for a %s.' % kind)
         else:
@@ -454,8 +453,7 @@ class Program(GLObject):
         return key in self._code_variables
 
     def __getitem__(self, name):
-        """ Get user-defined data for attributes and uniforms.
-        """
+        """Get user-defined data for attributes and uniforms."""
         if name in self._user_variables:
             return self._user_variables[name]
         elif name in self._pending_variables:
@@ -464,27 +462,27 @@ class Program(GLObject):
             raise KeyError("Unknown uniform or attribute %s" % name)
 
     def draw(self, mode='triangles', indices=None, check_error=True):
-        """ Draw the attribute arrays in the specified mode.
+        """Draw the attribute arrays in the specified mode.
 
         Parameters
         ----------
         mode : str | GL_ENUM
-            'points', 'lines', 'line_strip', 'line_loop', 'triangles',
-            'triangle_strip', or 'triangle_fan'.
+            'points', 'lines', 'line_strip', 'line_loop', 'lines_adjacency',
+            'line_strip_adjacency', 'triangles', 'triangle_strip', or
+            'triangle_fan'.
         indices : array
             Array of indices to draw.
         check_error:
             Check error after draw.
-
         """
-
         # Invalidate buffer (data has already been sent)
         self._buffer = None
 
         # Check if mode is valid
         mode = check_enum(mode)
         if mode not in ['points', 'lines', 'line_strip', 'line_loop',
-                        'triangles', 'triangle_strip', 'triangle_fan']:
+                        'lines_adjacency', 'line_strip_adjacency', 'triangles',
+                        'triangle_strip', 'triangle_fan']:
             raise ValueError('Invalid draw mode: %r' % mode)
 
         # Check leftover variables, warn, discard them
@@ -497,13 +495,25 @@ class Program(GLObject):
         # Check attribute sizes
         attributes = [vbo for vbo in self._user_variables.values()
                       if isinstance(vbo, DataBuffer)]
-        sizes = [a.size for a in attributes]
-        if len(attributes) < 1:
+
+        attrs = [a for a in attributes if getattr(a, 'divisor', None) is None]
+        if len(attrs) < 1:
             raise RuntimeError('Must have at least one attribute')
+        sizes = [a.size for a in attrs]
         if not all(s == sizes[0] for s in sizes[1:]):
-            msg = '\n'.join(['%s: %s' % (str(a), a.size) for a in attributes])
-            raise RuntimeError('All attributes must have the same size, got:\n'
-                               '%s' % msg)
+            msg = '\n'.join([f'{str(a)}: {a.size}' for a in attrs])
+            raise RuntimeError(f'All attributes must have the same size, got:\n{msg}')
+
+        attrs_with_div = [a for a in attributes if a not in attrs]
+        if attrs_with_div:
+            sizes = [a.size for a in attrs_with_div]
+            divs = [a.divisor for a in attrs_with_div]
+            instances = sizes[0] * divs[0]
+            if not all(s * d == instances for s, d in zip(sizes, divs)):
+                msg = '\n'.join([f'{str(a)}: {a.size} * {a.divisor} = {a.size * a.divisor}' for a in attrs_with_div])
+                raise RuntimeError(f'All attributes with divisors must have the same size as the number of instances, got:\n{msg}')
+        else:
+            instances = 1
 
         # Get the glir queue that we need now
         canvas = get_current_canvas()
@@ -520,11 +530,11 @@ class Program(GLObject):
                        np.dtype(np.uint16): 'UNSIGNED_SHORT',
                        np.dtype(np.uint32): 'UNSIGNED_INT'}
             selection = indices.id, gltypes[indices.dtype], indices.size
-            canvas.context.glir.command('DRAW', self._id, mode, selection)
+            canvas.context.glir.command('DRAW', self._id, mode, selection, instances)
         elif indices is None:
             selection = 0, attributes[0].size
             logger.debug("Program drawing %r with %r" % (mode, selection))
-            canvas.context.glir.command('DRAW', self._id, mode, selection)
+            canvas.context.glir.command('DRAW', self._id, mode, selection, instances)
         else:
             raise TypeError("Invalid index: %r (must be IndexBuffer)" %
                             indices)
