@@ -8,7 +8,6 @@ import numpy as np
 from copy import deepcopy
 
 from . import gl
-from ..ext.six import string_types
 from ..color import Color
 from ..util import logger
 
@@ -23,14 +22,19 @@ __all__ = ('set_viewport', 'set_depth_range', 'set_front_face',  # noqa
            'get_state_presets', 'set_state', 'finish', 'flush',  # noqa
            'read_pixels', 'set_hint',  # noqa
            'get_gl_configuration', '_check_valid',
+           'GL_PRESETS',
            'GlooFunctions', 'global_gloo_functions', )
 
 _setters = [s[4:] for s in __all__
             if s.startswith('set_') and s != 'set_state']
 
 # NOTE: If these are updated to have things beyond glEnable/glBlendFunc
-# calls, set_preset_state will need to be updated to deal with it.
-_gl_presets = {
+# calls, set_state will need to be updated to deal with it.
+#: Some OpenGL state presets for common use cases: 'opaque', 'translucent',
+#: 'additive'.
+#:
+#: To be used in :func:`.set_state`.
+GL_PRESETS = {
     'opaque': dict(
         depth_test=True,
         cull_face=False,
@@ -39,17 +43,19 @@ _gl_presets = {
         depth_test=True,
         cull_face=False,
         blend=True,
-        blend_func=('src_alpha', 'one_minus_src_alpha')),
+        blend_func=('src_alpha', 'one_minus_src_alpha', 'zero', 'one'),
+        blend_equation='func_add'),
     'additive': dict(
         depth_test=False,
         cull_face=False,
         blend=True,
-        blend_func=('src_alpha', 'one')),
+        blend_func=('src_alpha', 'one'),
+        blend_equation='func_add'),
 }
 
 
 def get_current_canvas():
-    """ Proxy for context.get_current_canvas to avoud circular import.
+    """Proxy for context.get_current_canvas to avoud circular import.
     This function replaces itself with the real function the first
     time it is called. (Bah)
     """
@@ -78,13 +84,13 @@ def _check_conversion(key, valid_dict):
     """Check for existence of key in dict, return value or raise error"""
     if key not in valid_dict and key not in valid_dict.values():
         # Only show users the nice string values
-        keys = [v for v in valid_dict.keys() if isinstance(v, string_types)]
+        keys = [v for v in valid_dict.keys() if isinstance(v, str)]
         raise ValueError('value must be one of %s, not %s' % (keys, key))
     return valid_dict[key] if key in valid_dict else key
 
 
 class BaseGlooFunctions(object):
-    """ Class that provides a series of GL functions that do not fit
+    """Class that provides a series of GL functions that do not fit
     in the object oriented part of gloo. An instance of this class is
     associated with each canvas.
     """
@@ -429,29 +435,29 @@ class BaseGlooFunctions(object):
     #
 
     def get_state_presets(self):
-        """The available GL state presets
+        """The available GL state :data:`presets <.GL_PRESETS>`.
 
         Returns
         -------
         presets : dict
-            The dictionary of presets usable with ``set_options``.
+            The dictionary of presets usable with :func:`.set_state`.
         """
-        return deepcopy(_gl_presets)
+        return deepcopy(GL_PRESETS)
 
     def set_state(self, preset=None, **kwargs):
-        """Set OpenGL rendering state, optionally using a preset
+        """Set the OpenGL rendering state, optionally using a preset.
 
         Parameters
         ----------
-        preset : str | None
-            Can be one of ('opaque', 'translucent', 'additive') to use
-            use reasonable defaults for these typical use cases.
+        preset : {'opaque', 'translucent', 'additive'}, optional
+            A named state :data:`preset <.GL_PRESETS>` for typical use cases.
+
         **kwargs : keyword arguments
             Other supplied keyword arguments will override any preset defaults.
             Options to be enabled or disabled should be supplied as booleans
             (e.g., ``'depth_test=True'``, ``cull_face=False``), non-boolean
             entries will be passed as arguments to ``set_*`` functions (e.g.,
-            ``blend_func=('src_alpha', 'one')`` will call ``set_blend_func``).
+            ``blend_func=('src_alpha', 'one')`` will call :func:`.set_blend_func`).
 
         Notes
         -----
@@ -494,8 +500,8 @@ class BaseGlooFunctions(object):
 
         # Load preset, if supplied
         if preset is not None:
-            _check_valid('preset', preset, tuple(list(_gl_presets.keys())))
-            for key, val in _gl_presets[preset].items():
+            _check_valid('preset', preset, tuple(list(GL_PRESETS.keys())))
+            for key, val in GL_PRESETS[preset].items():
                 # only overwrite user input with preset if user's input is None
                 if key not in kwargs:
                     kwargs[key] = val
@@ -510,6 +516,16 @@ class BaseGlooFunctions(object):
                 self.glir.command('FUNC', 'glEnable', 'cull_face')
                 self.set_cull_face(*_to_args(cull_face))
 
+        # Line width needs some special care ...
+        if 'line_width' in kwargs:
+            line_width = kwargs.pop('line_width')
+            self.glir.command('FUNC', 'glLineWidth', line_width)
+        if 'line_smooth' in kwargs:
+            line_smooth = kwargs.pop('line_smooth')
+            funcname = 'glEnable' if line_smooth else 'glDisable'
+            line_smooth_enum_value = 2848  # int(GL.GL_LINE_SMOOTH)
+            self.glir.command('FUNC', funcname, line_smooth_enum_value)
+
         # Iterate over kwargs
         for key, val in kwargs.items():
             if key in _setters:
@@ -517,7 +533,7 @@ class BaseGlooFunctions(object):
                 args = _to_args(val)
                 # these actually need tuples
                 if key in ('blend_color', 'clear_color') and \
-                        not isinstance(args[0], string_types):
+                        not isinstance(args[0], str):
                     args = [args]
                 getattr(self, 'set_' + key)(*args)
             else:
@@ -567,7 +583,7 @@ class BaseGlooFunctions(object):
         mode : str
             The mode to set (e.g., 'fastest', 'nicest', 'dont_care').
         """
-        if not all(isinstance(tm, string_types) for tm in (target, mode)):
+        if not all(isinstance(tm, str) for tm in (target, mode)):
             raise TypeError('target and mode must both be strings')
         self.glir.command('FUNC', 'glHint', target, mode)
 
@@ -576,8 +592,7 @@ class GlooFunctions(BaseGlooFunctions):
 
     @property
     def glir(self):
-        """ The GLIR queue corresponding to the current canvas
-        """
+        """The GLIR queue corresponding to the current canvas"""
         canvas = get_current_canvas()
         if canvas is None:
             msg = ("If you want to use gloo without vispy.app, " +
@@ -586,7 +601,7 @@ class GlooFunctions(BaseGlooFunctions):
         return canvas.context.glir
 
 
-## Create global functions object and inject names here
+# Create global functions object and inject names here
 
 # GlooFunctions without queue: use queue of canvas that is current at call-time
 global_gloo_functions = GlooFunctions()
@@ -599,7 +614,7 @@ for name in dir(global_gloo_functions):
         globals()[name] = fun
 
 
-## Functions that do not use the glir queue
+# Functions that do not use the glir queue
 
 
 def read_pixels(viewport=None, alpha=True, mode='color', out_type='unsigned_byte'):
