@@ -19,7 +19,6 @@ from ._sdf_cpu import _calc_distance_field
 from ...gloo import (TextureAtlas, IndexBuffer, VertexBuffer)
 from ...gloo import context
 from ...gloo.wrappers import _check_valid
-from ...ext.six import string_types
 from ...util.fonts import _load_glyph
 from ..transforms import STTransform
 from ...color import ColorArray
@@ -46,6 +45,7 @@ class TextureFont(object):
         SDF renderer to use.
 
     """
+
     def __init__(self, font, renderer):
         self._atlas = TextureAtlas(dtype=np.uint8)
         self._atlas.wrapping = 'clamp_to_edge'
@@ -75,7 +75,7 @@ class TextureFont(object):
         return self._spread // self.ratio
 
     def __getitem__(self, char):
-        if not (isinstance(char, string_types) and len(char) == 1):
+        if not (isinstance(char, str) and len(char) == 1):
             raise TypeError('index must be a 1-character string')
         if char not in self._glyphs:
             self._load_char(char)
@@ -89,7 +89,7 @@ class TextureFont(object):
         char : str
             A single character to be represented.
         """
-        assert isinstance(char, string_types) and len(char) == 1
+        assert isinstance(char, str) and len(char) == 1
         assert char not in self._glyphs
         # load new glyph data from font
         _load_glyph(self._font, char, self._glyphs)
@@ -122,11 +122,12 @@ class TextureFont(object):
 
 class FontManager(object):
     """Helper to create TextureFont instances and reuse them when possible"""
+
     # XXX: should store a font-manager on each context,
     # or let TextureFont use a TextureAtlas for each context
     def __init__(self, method='cpu'):
         self._fonts = {}
-        if not isinstance(method, string_types) or \
+        if not isinstance(method, str) or \
                 method not in ('cpu', 'gpu'):
             raise ValueError('method must be "cpu" or "gpu", got %s (%s)'
                              % (method, type(method)))
@@ -147,6 +148,91 @@ class FontManager(object):
 ##############################################################################
 # The visual
 
+_VERTEX_SHADER = """
+    attribute float a_rotation;  // rotation in rad
+    attribute vec2 a_position; // in point units
+    attribute vec2 a_texcoord;
+    attribute vec3 a_pos;  // anchor position
+    varying vec2 v_texcoord;
+    varying vec4 v_color;
+
+    void main(void) {
+        // Eventually "rot" should be handled by SRTTransform or so...
+        mat4 rot = mat4(cos(a_rotation), -sin(a_rotation), 0, 0,
+                        sin(a_rotation), cos(a_rotation), 0, 0,
+                        0, 0, 1, 0, 0, 0, 0, 1);
+        vec4 pos = $transform(vec4(a_pos, 1.0)) +
+                   vec4($text_scale(rot * vec4(a_position, 0.0, 1.0)).xyz, 0.0);
+        gl_Position = pos;
+        v_texcoord = a_texcoord;
+        v_color = $color;
+    }
+    """
+
+_FRAGMENT_SHADER = """
+    // Extensions for WebGL
+    #extension GL_OES_standard_derivatives : enable
+    #extension GL_OES_element_index_uint : enable
+    #include "misc/spatial-filters.frag"
+    // Adapted from glumpy with permission
+    const float M_SQRT1_2 = 0.707106781186547524400844362104849039;
+
+    uniform sampler2D u_font_atlas;
+    uniform vec2 u_font_atlas_shape;
+    varying vec4 v_color;
+    uniform float u_npix;
+
+    varying vec2 v_texcoord;
+    const float center = 0.5;
+
+    float contour(in float d, in float w)
+    {
+        return smoothstep(center - w, center + w, d);
+    }
+
+    float sample(sampler2D texture, vec2 uv, float w)
+    {
+        return contour(texture2D(texture, uv).r, w);
+    }
+
+    void main(void) {
+        vec2 uv = v_texcoord.xy;
+        vec4 rgb;
+
+        // Use interpolation at high font sizes
+        if(u_npix >= 50.0)
+            rgb = CatRom2D(u_font_atlas, u_font_atlas_shape, uv);
+        else
+            rgb = texture2D(u_font_atlas, uv);
+        float distance = rgb.r;
+
+        // GLSL's fwidth = abs(dFdx(uv)) + abs(dFdy(uv))
+        float width = 0.5 * fwidth(distance);  // sharpens a bit
+
+        // Regular SDF
+        float alpha = contour(distance, width);
+
+        if (u_npix < 30.) {
+            // Supersample, 4 extra points
+            // Half of 1/sqrt2; you can play with this
+            float dscale = 0.5 * M_SQRT1_2;
+            vec2 duv = dscale * (dFdx(v_texcoord) + dFdy(v_texcoord));
+            vec4 box = vec4(v_texcoord-duv, v_texcoord+duv);
+            float asum = sample(u_font_atlas, box.xy, width)
+                       + sample(u_font_atlas, box.zw, width)
+                       + sample(u_font_atlas, box.xw, width)
+                       + sample(u_font_atlas, box.zy, width);
+            // weighted average, with 4 extra points having 0.5 weight
+            // each, so 1 + 0.5*4 = 3 is the divisor
+            alpha = (alpha + 0.5 * asum) / 3.0;
+        }
+
+        if (alpha <= 0) discard;
+
+        gl_FragColor = vec4(v_color.rgb, v_color.a * alpha);
+    }
+    """
+
 
 def _text_to_vbo(text, font, anchor_x, anchor_y, lowres_size):
     """Convert text characters to VBO"""
@@ -280,9 +366,6 @@ def _text_to_vbo(text, font, anchor_x, anchor_y, lowres_size):
 class TextVisual(Visual):
     """Visual that displays text
 
-    Note: SDF GPU is not currently supported in WebGL without additional
-          extensions (see comments in fragment shader below).
-
     Parameters
     ----------
     text : str | list of str
@@ -310,102 +393,26 @@ class TextVisual(Visual):
         Vertical text anchor.
     method : str
         Rendering method for text characters. Either 'cpu' (default) or
-        'gpu'. The 'cpu' method should perform better on remote backends
-        like those based on WebGL. The 'gpu' method should produce higher
-        quality results.
+        'gpu'. The 'cpu' method should perform better on remote backends.
+        The 'gpu' method should produce higher quality results.
     font_manager : object | None
         Font manager to use (can be shared if the GLContext is shared).
+    depth_test : bool
+        Whether to apply depth testing. Default False. If False, the text
+        behaves like an overlay that does not get hidden behind other
+        visuals in the scene.
     """
 
-    VERTEX_SHADER = """
-        attribute float a_rotation;  // rotation in rad
-        attribute vec2 a_position; // in point units
-        attribute vec2 a_texcoord;
-        attribute vec3 a_pos;  // anchor position
-        varying vec2 v_texcoord;
-        varying vec4 v_color;
-
-        void main(void) {
-            // Eventually "rot" should be handled by SRTTransform or so...
-            mat4 rot = mat4(cos(a_rotation), -sin(a_rotation), 0, 0,
-                            sin(a_rotation), cos(a_rotation), 0, 0,
-                            0, 0, 1, 0, 0, 0, 0, 1);
-            vec4 pos = $transform(vec4(a_pos, 1.0)) +
-                       $text_scale(rot * vec4(a_position, 0, 0));
-            gl_Position = pos;
-            v_texcoord = a_texcoord;
-            v_color = $color;
-        }
-        """
-
-    FRAGMENT_SHADER = """
-        // Extensions for WebGL
-        #extension GL_OES_standard_derivatives : enable
-        #extension GL_OES_element_index_uint : enable
-        #include "misc/spatial-filters.frag"
-        // Adapted from glumpy with permission
-        const float M_SQRT1_2 = 0.707106781186547524400844362104849039;
-
-        uniform sampler2D u_font_atlas;
-        uniform vec2 u_font_atlas_shape;
-        varying vec4 v_color;
-        uniform float u_npix;
-
-        varying vec2 v_texcoord;
-        const float center = 0.5;
-
-        float contour(in float d, in float w)
-        {
-            return smoothstep(center - w, center + w, d);
-        }
-
-        float sample(sampler2D texture, vec2 uv, float w)
-        {
-            return contour(texture2D(texture, uv).r, w);
-        }
-
-        void main(void) {
-            vec2 uv = v_texcoord.xy;
-            vec4 rgb;
-
-            // Use interpolation at high font sizes
-            if(u_npix >= 50.0)
-                rgb = CatRom(u_font_atlas, u_font_atlas_shape, uv);
-            else
-                rgb = texture2D(u_font_atlas, uv);
-            float distance = rgb.r;
-
-            // GLSL's fwidth = abs(dFdx(uv)) + abs(dFdy(uv))
-            float width = 0.5 * fwidth(distance);  // sharpens a bit
-
-            // Regular SDF
-            float alpha = contour(distance, width);
-
-            if (u_npix < 30.) {
-                // Supersample, 4 extra points
-                // Half of 1/sqrt2; you can play with this
-                float dscale = 0.5 * M_SQRT1_2;
-                vec2 duv = dscale * (dFdx(v_texcoord) + dFdy(v_texcoord));
-                vec4 box = vec4(v_texcoord-duv, v_texcoord+duv);
-                float asum = sample(u_font_atlas, box.xy, width)
-                           + sample(u_font_atlas, box.zw, width)
-                           + sample(u_font_atlas, box.xw, width)
-                           + sample(u_font_atlas, box.zy, width);
-                // weighted average, with 4 extra points having 0.5 weight
-                // each, so 1 + 0.5*4 = 3 is the divisor
-                alpha = (alpha + 0.5 * asum) / 3.0;
-            }
-
-            gl_FragColor = vec4(v_color.rgb, v_color.a * alpha);
-        }
-        """
+    _shaders = {
+        'vertex': _VERTEX_SHADER,
+        'fragment': _FRAGMENT_SHADER,
+    }
 
     def __init__(self, text=None, color='black', bold=False,
                  italic=False, face='OpenSans', font_size=12, pos=[0, 0, 0],
                  rotation=0., anchor_x='center', anchor_y='center',
-                 method='cpu', font_manager=None):
-        Visual.__init__(self, vcode=self.VERTEX_SHADER,
-                        fcode=self.FRAGMENT_SHADER)
+                 method='cpu', font_manager=None, depth_test=False):
+        Visual.__init__(self, vcode=self._shaders['vertex'], fcode=self._shaders['fragment'])
         # Check input
         valid_keys = ('top', 'center', 'middle', 'baseline', 'bottom')
         _check_valid('anchor_y', anchor_y, valid_keys)
@@ -414,7 +421,10 @@ class TextVisual(Visual):
         # Init font handling stuff
         # _font_manager is a temporary solution to use global mananger
         self._font_manager = font_manager or FontManager(method=method)
-        self._font = self._font_manager.get_font(face, bold, italic)
+        self._face = face
+        self._bold = bold
+        self._italic = italic
+        self._update_font()
         self._vertices = None
         self._color_vbo = None
         self._anchors = (anchor_x, anchor_y)
@@ -426,7 +436,7 @@ class TextVisual(Visual):
         self.rotation = rotation
         self._text_scale = STTransform()
         self._draw_mode = 'triangles'
-        self.set_gl_state(blend=True, depth_test=False, cull_face=False,
+        self.set_gl_state(blend=True, depth_test=depth_test, cull_face=False,
                           blend_func=('src_alpha', 'one_minus_src_alpha'))
         self.freeze()
 
@@ -438,7 +448,7 @@ class TextVisual(Visual):
     @text.setter
     def text(self, text):
         if isinstance(text, list):
-            assert all(isinstance(t, string_types) for t in text)
+            assert all(isinstance(t, str) for t in text)
         if text is None:
             text = []
         self._text = text
@@ -460,8 +470,7 @@ class TextVisual(Visual):
 
     @property
     def font_size(self):
-        """ The font size (in points) of the text
-        """
+        """The font size (in points) of the text"""
         return self._font_size
 
     @font_size.setter
@@ -471,8 +480,7 @@ class TextVisual(Visual):
 
     @property
     def color(self):
-        """ The color of the text
-        """
+        """The color of the text"""
         return self._color
 
     @color.setter
@@ -483,8 +491,7 @@ class TextVisual(Visual):
 
     @property
     def rotation(self):
-        """ The rotation of the text (clockwise, in degrees)
-        """
+        """The rotation of the text (clockwise, in degrees)"""
         return self._rotation * 180. / np.pi
 
     @rotation.setter
@@ -495,8 +502,7 @@ class TextVisual(Visual):
 
     @property
     def pos(self):
-        """ The position of the text anchor in the local coordinate frame
-        """
+        """The position of the text anchor in the local coordinate frame"""
         return self._pos
 
     @pos.setter
@@ -519,7 +525,7 @@ class TextVisual(Visual):
             return False
         if self._vertices is None:
             text = self.text
-            if isinstance(text, string_types):
+            if isinstance(text, str):
                 text = [text]
             n_char = sum(len(t) for t in text)
             # we delay creating vertices because it requires a context,
@@ -539,7 +545,7 @@ class TextVisual(Visual):
         if self._pos_changed:
             # now we promote pos to the proper shape (attribute)
             text = self.text
-            if not isinstance(text, string_types):
+            if not isinstance(text, str):
                 repeats = [4 * len(t) for t in text]
                 text = ''.join(text)
             else:
@@ -567,7 +573,7 @@ class TextVisual(Visual):
         if self._color_changed:
             # now we promote color to the proper shape (varying)
             text = self.text
-            if not isinstance(text, string_types):
+            if not isinstance(text, str):
                 repeats = [4 * len(t) for t in text]
                 text = ''.join(text)
             else:
@@ -606,9 +612,41 @@ class TextVisual(Visual):
     def _compute_bounds(self, axis, view):
         return self._pos[:, axis].min(), self._pos[:, axis].max()
 
+    @property
+    def face(self):
+        return self._face
+
+    @face.setter
+    def face(self, value):
+        self._face = value
+        self._update_font()
+
+    @property
+    def bold(self):
+        return self._bold
+
+    @bold.setter
+    def bold(self, value):
+        self._bold = value
+        self._update_font()
+
+    @property
+    def italic(self):
+        return self._italic
+
+    @italic.setter
+    def italic(self, value):
+        self._italic = value
+        self._update_font()
+
+    def _update_font(self):
+        self._font = self._font_manager.get_font(self._face, self._bold, self._italic)
+        self.update()
+
 
 class SDFRendererCPU(object):
     """Render SDFs using the CPU."""
+
     # This should probably live in _sdf_cpu.pyx, but doing so makes
     # debugging substantially more annoying
     def render_to_texture(self, data, texture, offset, size):
