@@ -9,14 +9,14 @@ use with visuals and scenes.
 
 from .base_transform import BaseTransform  # noqa
 from .linear import (NullTransform, STTransform,  # noqa
-                     MatrixTransform,  MatrixTransform)  # noqa
+                     MatrixTransform)  # noqa
 from .nonlinear import LogTransform, PolarTransform  # noqa
 from .interactive import PanZoomTransform
 from .chain import ChainTransform  # noqa
 from ._util import arg_to_array, arg_to_vec4, as_vec4, TransformCache  # noqa
 from .transform_system import TransformSystem
 
-__all__ = ['NullTransform', 'STTransform', 'MatrixTransform',
+__all__ = ['NullTransform', 'STTransform',
            'MatrixTransform', 'LogTransform', 'PolarTransform',
            'ChainTransform', 'TransformSystem', 'PanZoomTransform']
 
